@@ -16,7 +16,7 @@ class ObjectProcessor(IObjectProcessor):
     HTTP client that implements object processing by delegating to the text-processing-service.
     """
 
-    def __init__(self, host: str = 'http://localhost:8081', route: str = '/api/v1/texts/image/objects'):
+    def __init__(self, host: str = 'http://localhost:8002', route: str = '/api/v1/texts/image'):
         """
         Initialize the adapter with the target text-processing-service URL.
 
@@ -29,21 +29,22 @@ class ObjectProcessor(IObjectProcessor):
         """
         self.url = f'{host.rstrip("/")}{route}'
 
-    def process_objects(self, object_data: ImageObjectInput) -> List[Dict[str, Any]]:
+    def process_objects(self, object_data: List[ImageObjectInput]) -> List[Dict[str, Any]]:
         """
         Send image object data to the text-processing-service for product detection.
 
         Parameters
         ----------
-        object_data : ImageObjectInput
-            DTO containing base64 image and metadata.
+        object_data : List[ImageObjectInput]
+            List of DTOs containing binary image data and metadata.
 
         Returns
         -------
         List[Dict[str, Any]]
-            List of extracted products from the object image.
+            List of extracted products from the object images.
         """
-        payload = object_data.model_dump()
+        payload = [obj.model_dump() for obj in object_data]
         response = requests.post(self.url, json=payload, timeout=10)
         response.raise_for_status()
         return response.json()
+
