@@ -6,7 +6,8 @@ to interact with the text-processing-service in a standardized way.
 """
 
 from abc import ABC, abstractmethod
-from typing import List, Any, Dict
+from typing import List, Any
+from isloth_text_processing_service_python_interface.dtos.image.ImageObjectInput import ImageObjectInput
 
 
 class IObjectProcessor(ABC):
@@ -15,13 +16,13 @@ class IObjectProcessor(ABC):
     """
 
     @abstractmethod
-    def process_objects(self, object_data: Dict[str, Any]) -> List[dict[str, Any]]:
+    def process_objects(self, object_data: List[ImageObjectInput]) -> List[dict[str, Any]]:
         """
         Process objects extracted from an image to detect products using BLIP captioning and helper logic.
 
         Parameters
         ----------
-        object_data : dict
+        object_data : ImageObjectInput
             Dictionary containing metadata and the cropped object from the original image (e.g., PIL.Image.Image).
 
         Returns
